function AndesGUI
% ANDY data processing
%   1. ACTION: Press "Pusbutton READ" 
%        - to read expedition data with excluded stops resampled to Ts=2s
%        - to plot all cycling data
%        - to evaluate and to show analysis of the whole expedition
%   2. ACTION: Press "Pusbutton PROCESS"  
%        - to plot data from time and window length defined by sliders
%        - to plot starting position into the main map
%        - to plot route segment into the 3D map
%        - to evaluate and to show analysis of the selected segment
%   3. ACTION: Press "Pusbutton SAVE"
%        - to save route segment data (indeces of a selected segment)
%        - to close the GUI 
% (C) Ales Prochazka 2017
  
%% A %% INITIALIZATION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     clear all; close all; clc;
     help AndesGUI
     dFont='Times'; sc=get(0,'ScreenSize');
     vs=round([0.05*sc(3) 0.10*sc(4) 0.7*sc(3) 0.8*sc(4)]);
   hFig=figure('Name','ANDY DATA ANALYSIS','Units','Pixels','Position',vs);
   global hAx5

%% B %%  GUI ELEMENTS LOCATION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
%% B1 %% Specification of axes location %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   hAx1=axes('Parent',hFig,'Units','Normalized',...
     'Position',[0.56 0.85 0.43 0.10],...
     'XTick',[],...
     'XTickLabel',[],...
     'YTick',[],...
     'YTickLabel',[],...
     'Box','on');
 
   hAx2=axes('Parent',hFig,'Units','Normalized',...
     'Position',[0.56 0.67 0.43 0.10],...
     'XTick',[],...
     'XTickLabel',[],...
     'YTick',[],...
     'YTickLabel',[],...
     'Title','Detail Signal Area',...
     'Box','on');

   hAx3=axes('Parent',hFig,'Units','Normalized',...
     'Position',[0.56 0.49 0.43 0.10],...
     'XTick',[],...
     'XTickLabel',[],...
     'YTick',[],...
     'YTickLabel',[],...
     'Box','on');

   hAx4=axes('Parent',hFig,'Units','Normalized',...
     'Position',[0.58 0.08 0.39 0.30],...
     'XTick',[],...
     'XTickLabel',[],...
     'YTick',[],...
     'YTickLabel',[],...
     'Box','on');

%% B2 %% Specification of the MAP and button area %%%%%%%%%%%%%%%%%%%%%%%%%
   hMainGroup=uibuttongroup(hFig,'Position',[0 0 0.5 1]); 
   
   hAx5=axes('Parent',hMainGroup,'Units','Normalized',...
     'Position',[0.02 0.32 0.96 0.66],...
     'XTick',[],...
     'XTickLabel',[],...
     'YTick',[],...
     'YTickLabel',[],...
     'Box','on');

%% Specification of subbutton area %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
   hMenu4=uibuttongroup(hMainGroup,'Position',[0.01 0.01 0.98 0.30],...
        'BackgroundColor',[0.7 0.8 0.7],...
        'FontSize',10,...
        'Title','     PARAMETERS'); 
  
  hRead1=uicontrol(hMenu4,'Style','pushbutton',...
    'FontName',dFont,...   
    'FontSize',10,...
    'FontWeight','bold',...
    'String',['Read'],...
    'Units','Normalized',...  
    'BackgroundColor',[0.4 0.4 1],...
    'ForegroundColor',[1 1 1],... 
    'Position',[0.05 0.7 0.2 0.2],...
    'Callback',@Start);

  hProcess1=uicontrol(hMenu4,'Style','pushbutton',...
    'FontName',dFont,...   
    'FontSize',10,...
    'FontWeight','bold',...
    'String',['Process'],...
    'Units','Normalized',...  
    'BackgroundColor',[0.4 0.4 1],...
    'ForegroundColor',[1 1 1],... 
    'Position',[0.05 0.4 0.2 0.2],...
    'Callback',@Process);

  hWrite1=uicontrol(hMenu4,'Style','pushbutton',...
    'FontName',dFont,...   
    'FontSize',10,...
    'FontWeight','bold',...
    'String',['Save'],...
    'Units','Normalized',...  
    'BackgroundColor',[0.4 0.4 1],...
    'ForegroundColor',[1 1 1],... 
    'Position',[0.05 0.1 0.2 0.2],...
    'Callback',@DataWrite);
 
  hSlider1=uicontrol(hMenu4,'Style','slider',...
    'FontName',dFont,...   
    'FontSize',8,...
    'FontWeight','bold',...
    'Units','Normalized',...
    'Min',0,'Max',262,...
    'SliderStep',[0.0002 0.002],...
    'BackgroundColor',[0.4 0.4 1],...  
    'Position',[0.3 0.7 0.68 0.12],...
    'Callback',@WINbegin);

  hText1=uicontrol(hMenu4,'Style','text',...
    'FontName',dFont,...   
    'FontSize',8,...
    'FontWeight','bold',...
    'Units','Normalized',...
    'String','WINDOW BEGINNING',...
    'Position',[0.43 0.85 0.4 0.08]);

  hSlider2=uicontrol(hMenu4,'Style','slider',...
    'FontName',dFont,...   
    'FontSize',8,...
    'FontWeight','bold',...
    'Units','Normalized',...
    'Min',0,'Max',10,...
    'SliderStep',[0.002 0.02],...
    'BackgroundColor',[0.4 0.4 1],...  
    'Position',[0.3 0.4 0.68 0.12],...
    'Callback',@WINlength);

  hText1=uicontrol(hMenu4,'Style','text',...
    'FontName',dFont,...   
    'FontSize',8,...
    'FontWeight','bold',...
    'Units','Normalized',...
    'String','WINDOW LENGTH',...
    'Position',[0.43 0.55 0.4 0.08]);

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  hEdit1=uicontrol(hMenu4,'Style','edit',...
    'FontName',dFont,...   
    'FontSize',10,...
    'FontWeight','bold',...
    'String','[km]',...
    'ForegroundColor',[0.4 0.4 0.4],...
    'Units','Normalized',...
    'Position',[0.3 0.1 0.18 0.12]);

  hTextE1=uicontrol(hMenu4,'Style','text',...
    'FontName',dFont,...   
    'FontSize',8,...
    'FontWeight','bold',...
    'Units','Normalized',...
    'String','START [km]',...
    'Position',[0.3 0.25 0.18 0.08]);

  hEdit2=uicontrol(hMenu4,'Style','edit',...
    'FontName',dFont,...   
    'FontSize',10,...
    'FontWeight','bold',...
    'String','[km]',...
    'ForegroundColor',[0.4 0.4 0.4],...
    'Units','Normalized',...
    'Position',[0.55 0.1 0.18 0.12]);

  hTextE2=uicontrol(hMenu4,'Style','text',...
    'FontName',dFont,...   
    'FontSize',8,...
    'FontWeight','bold',...
    'Units','Normalized',...
    'String','LENGTH [km]',...
    'Position',[0.55 0.25 0.18 0.08]);

  hEdit3=uicontrol(hMenu4,'Style','edit',...
    'FontName',dFont,...   
    'FontSize',10,...
    'FontWeight','bold',...
    'String','[km/h]',...
    'ForegroundColor',[0.4 0.4 0.4],...
    'Units','Normalized',...
    'Position',[0.8 0.1 0.18 0.12]);

  hTextE3=uicontrol(hMenu4,'Style','text',...
    'FontName',dFont,...   
    'FontSize',8,...
    'FontWeight','bold',...
    'Units','Normalized',...
    'String','SPEED [km/h]',...
    'Position',[0.8 0.25 0.18 0.08]);

%% C %% SPECIFICATION OF FUNCTIONS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
axes(hAx5); tr1=text(0.25, 0.65, 'PLEASE','FontSize',18,'FontWeight','bold','Color','b');
            tr2=text(0.05, 0.5, '1. PRESS READ TO LOAD DATA','FontSize',12,'FontWeight','bold','Color','b');
            tr3=text(0.05, 0.4, '2. USE SLIDERS TO DEFINE WINDOWS','FontSize',12,'FontWeight','bold','Color','b');
            tr4=text(0.05, 0.3, '3. PRESS PROCESS TO ANALYZE SELECTION','FontSize',12,'FontWeight','bold','Color','b');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    function Start(~,~)
%   ACTION: Press "Pusbutton READ" 
%        - to read expedition data with excluded stops resampled to Ts=2s
%        - to plot all cycling data
%        - to evaluate and to show analysis of the whole expedition

   global Time6 DistanceMetersINTERP AltitudeMetersINTERP LongitudeINTERP ...
          LatitudeINTERP SpeedINTERP HeartRateBpmINTERP hhh1 hhh2 ti1 ti2 
 
   D=imread('MapANDY3.jpg'); D2=imread('MapANDY3d.jpg');
   load('DataAndyINTERP.mat','Time6','AltitudeMetersINTERP','LongitudeINTERP',...
        'LatitudeINTERP','SpeedINTERP','HeartRateBpmINTERP','DistanceMetersINTERP')
   axes(hAx5)
       CyclingDistanceKM=DistanceMetersINTERP(end)/1000;  
       CyclingTimeHOD=Time6(end)/60/60;
       AverageCyclingSpeedKMHOD=CyclingDistanceKM/CyclingTimeHOD;
     iii=imagesc(D); axis off
     v=[282.5 1998.8 1144.4 99.7]; s=[-75 -40 -42 -22]; % MapANDY3.jpg
     Long1=LongitudeINTERP(1); Lat1=LatitudeINTERP(1);
       LongN1=v(1)+(Long1-s(1))/(s(2)-s(1))*(v(2)-v(1));
       LatN1=v(3)+(Lat1-s(3))/(s(4)-s(3))*(v(4)-v(3));
     Long2=LongitudeINTERP(end); Lat2=LatitudeINTERP(end);
       LongN2=v(1)+(Long2-s(1))/(s(2)-s(1))*(v(2)-v(1));
       LatN2=v(3)+(Lat2-s(3))/(s(4)-s(3))*(v(4)-v(3));  
     hold on; hhh1=plot(LongN1,LatN1,'bo','MarkerSize',6,'LineWidth',2); 
              hhh2=plot(LongN2,LatN2,'ro','MarkerSize',6,'LineWidth',2); hold off
     set(hEdit1,'String',['0 [km]']);
     set(hEdit2,'String',[num2str(round(CyclingDistanceKM)),' [km]']);
     set(hEdit3,'String',[num2str(round(AverageCyclingSpeedKMHOD*10)/10),' [kmph]']);
       ti1=text(v(1)+450,v(3)-100,['Starting Index/Time: ',num2str(1),...
                          ' / ', num2str(0) ],'FontSize',10,'Color','k');
       ti2=text(v(1)+450,v(3)-50,['Final Index/Time: ',num2str(length(LatitudeINTERP)),...
                          ' / ', num2str(round(Time6(end)/60/60*10)/10), ' h' ],'FontSize',10,'Color','r');

   axes(hAx1)
     plot(Time6/60/60,AltitudeMetersINTERP,'Color','k');
         title('ALTITUDE PROFILE'); 
         ylabel('Altitude [m]'); grid on; axis tight
   axes(hAx2)
      plot(Time6/60/60,SpeedINTERP,'Color','k'); 
        R1=corrcoef([0 diff(AltitudeMetersINTERP)],SpeedINTERP); R1c=abs(R1(1,2));
        title(['SPEED PROFILE / CorrCoef-with Speed= ',num2str(round(R1c*100)/100)]);
        ylabel('Speed [km/h]'); grid on; axis tight
   axes(hAx3)
      plot(Time6/60/60,HeartRateBpmINTERP,'Color','k');
         R2=corrcoef(HeartRateBpmINTERP,[0 diff(AltitudeMetersINTERP)]); R2c=abs(R2(1,2));
         title(['HEART RATE / CorrCoef-with Altitude Gradient= ',num2str(round(R2c*100)/100)]);
         xlabel('Time [hours]'); ylabel('Heart Rate [bpm]'); grid on; axis tight
   axes(hAx4)
     lonVec=[-75 -40];latVec=[-22 -42];
     plot3(LongitudeINTERP,LatitudeINTERP, AltitudeMetersINTERP,...
        'Color','k'); view(-31,25); 
        axis([lonVec(1) lonVec(2) latVec(2) latVec(1) 0 +inf]); grid on
     hold on; plot3(LongitudeINTERP,LatitudeINTERP,...
              zeros(1,length(AltitudeMetersINTERP)),'Color','k'); hold off
     title('CYCLING ROUTE'); xlabel('Longitude'); ylabel('Latitude'); 
                             zlabel('Altitude [m]')
     hold on; image(lonVec,latVec,D2); hold off                        
    end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    function Process(~,~)
%   ACTION: Press "Pusbutton PROCESS"  
%        - to plot data from time and window length defined by sliders
%        - to plot starting position into the main map
%        - to plot route segment into the 3D map
%        - to evaluate and to show analysis of the selected segment
   global Time6 DistanceMetersINTERP AltitudeMetersINTERP LongitudeINTERP ...
          LatitudeINTERP SpeedINTERP HeartRateBpmINTERP I1 I2 hhh1 hhh2 ti1 ti2
 
   axes(hAx5)
       delete(hhh1); delete(hhh2); delete(ti1); delete(ti2)
       S1=get(hSlider1); WB=S1.Value;
       S2=get(hSlider2); WL=S2.Value+0.1;
       I1=round(WB*60*30+1); I2d=round(WL*60*60/2); I2=I1+I2d;
     v0=[282.5 1998.8 1144.4 99.7]; v=[1 1463 817 1]; s=[-75 -40 -42 -22]; % MapANDY3.jpg
     s1=[min(LongitudeINTERP(I1:I2)) ...
         max(LongitudeINTERP(I1:I2)) ...
         min(LatitudeINTERP(I1:I2)) ...
         max(LatitudeINTERP(I1:I2))];
     v1(1)=v(1)+(s1(1)-s(1))/(s(2)-s(1))*(v(2)-v(1));
     v1(2)=v(1)+(s1(2)-s(1))/(s(2)-s(1))*(v(2)-v(1));
     v1(3)=v(3)+(s1(3)-s(3))/(s(4)-s(3))*(v(4)-v(3));
     v1(4)=v(3)+(s1(4)-s(3))/(s(4)-s(3))*(v(4)-v(3));
        Long1=LongitudeINTERP(I1); Lat1=LatitudeINTERP(I1); 
          LongN1=v0(1)+(Long1-s(1))/(s(2)-s(1))*(v0(2)-v0(1));
          LatN1=v0(3)+(Lat1-s(3))/(s(4)-s(3))*(v0(4)-v0(3));
        Long2=LongitudeINTERP(I2); Lat2=LatitudeINTERP(I2); 
          LongN2=v0(1)+(Long2-s(1))/(s(2)-s(1))*(v0(2)-v0(1));
          LatN2=v0(3)+(Lat2-s(3))/(s(4)-s(3))*(v0(4)-v0(3));   
     hold on; hhh1=plot(LongN1,LatN1,'bo','MarkerSize',6,'LineWidth',2); 
              hhh2=plot(LongN2,LatN2,'ro','MarkerSize',6,'LineWidth',2); 
     hold off
     set(hEdit1,'String',[num2str(round(DistanceMetersINTERP(I1)/1000)),' [km]']);
     set(hEdit2,'String',...
         [num2str(round((DistanceMetersINTERP(I2)-DistanceMetersINTERP(I1))/1000*10)/10),...
         ' [km]']);
       CyclingDistanceKM=(DistanceMetersINTERP(I2)-DistanceMetersINTERP(I1))/1000;  
       CyclingTimeHOD=(Time6(I2)-Time6(I1))/60/60;
       AverageCyclingSpeedKMHOD=CyclingDistanceKM/CyclingTimeHOD;
     set(hEdit3,'String',[num2str(round(AverageCyclingSpeedKMHOD)),' [kmph]']);
     ti1=text(v0(1)+450,v0(3)-100,['Starting Index/Time: ',num2str(I1),...
                          ' / ', num2str(round(Time6(I1)/60/60*10)/10), ' h' ],'FontSize',10,'Color','b');
     ti2=text(v0(1)+450,v0(3)-50,['Final Index/Time: ',num2str(I2),...
                          ' / ', num2str(round(Time6(I2)/60/60*10)/10), ' h' ],'FontSize',10,'Color','r');                 
                      
   axes(hAx1)
      plot(Time6(I1:I2)/60/60,AltitudeMetersINTERP(I1:I2),'Color','k');
         title('ALTITUDE PROFILE'); 
         ylabel('Altitude [m]'); grid on; axis tight
   axes(hAx2)
      plot(Time6(I1:I2)/60/60,SpeedINTERP(I1:I2),'Color','k'); 
        R1=corrcoef([0 diff(AltitudeMetersINTERP(I1:I2))],SpeedINTERP(I1:I2)); R1c=abs(R1(1,2));
        title(['SPEED PROFILE / CorrCoef-with Speed= ',num2str(round(R1c*100)/100)]);
        ylabel('Speed [km/h]'); grid on; axis tight
   axes(hAx3)
      plot(Time6(I1:I2)/60/60,HeartRateBpmINTERP(I1:I2),'Color','k');
         R2=corrcoef(HeartRateBpmINTERP(I1:I2),[0 diff(AltitudeMetersINTERP(I1:I2))]); R2c=abs(R2(1,2));
         title(['HEART RATE / CorrCoef-with Altitude Gradient= ',num2str(round(R2c*100)/100)]);
         xlabel('Time [hours]'); ylabel('Heart Rate [bpm]'); grid on; axis tight
   
   delete(get(hAx4,'Children'));
   axes(hAx4)
     lonVec=[s1(1) s1(2)];latVec=[s1(3) s1(4)];
     plot3(LongitudeINTERP(I1:I2),LatitudeINTERP(I1:I2), AltitudeMetersINTERP(I1:I2),...
        'Marker','.','MarkerSize',4,'Color','b'); view(-31,25); 
        axis([lonVec(1) lonVec(2) latVec(1) latVec(2) 0 +inf]); grid on
     hold on; plot3(LongitudeINTERP(I1:I2),LatitudeINTERP(I1:I2),...
              zeros(1,length(AltitudeMetersINTERP(I1:I2))),...
              'Marker','.','MarkerSize',0.5,'Color','k'); hold off
     title('CYCLING ROUTE'); xlabel('Longitude'); ylabel('Latitude'); 
                             zlabel('Altitude [m]')
   end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    function WINbegin(~,~)
%   Function used to define the window beginning
          S1=get(hSlider1); t1=S1.Value; % Process 
    end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    function WINlength(~,~)
%   Function used to define the window length
          S2=get(hSlider2); t2=S2.Value;  % Process 
    end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    function DataWrite(~,~)
%   ACTION: Press "Pusbutton SAVE"
%        - to save route segment data
%        - to close the GUI
    global I1 I2
        save RESULTS I1 I2
        delete(get(0,'Children'));
    end

end